
shelephant
==========

.. toctree::
   :caption: BASICS
   :maxdepth: 1

   getting.rst

.. toctree::
   :caption: API
   :maxdepth: 1

   cli.rst
   python.rst

.. toctree::
   :caption: DEVELOP
   :maxdepth: 1

   changelog.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
